@@ -1,13 +1,19 @@
 import typing
 
-from .config import *
 from .errors import *
+from .logging import *
+from .sqlite import *
 from .worker import *
 
 __all__: typing.List[str] = [
-    "Worker",
-    "Logger",
+    "S2PLogger",
     "Sqlite2pgError",
     "SqliteError",
+    "LoggingConfigError",
     "PostgresError",
+    "get_tables",
+    "get_schema",
+    "Worker",
+    "CleanSchemaT",
+    "sqlite",
 ]
