@@ -1,17 +1,14 @@
-import abc
 import typing
 
-
 __all__: typing.List[str] = [
     "Sqlite2pgError",
     "SqliteError",
     "PostgresError",
+    "LoggingConfigError",
 ]
 
 
 # Do we need these???
-
-
 class Sqlite2pgError(Exception):
     """Base Exception that all sqlite2pg exceptions inherit from."""
 
@@ -31,3 +28,10 @@ class PostgresError(Sqlite2pgError):
 
     __slots__: typing.Sequence[str] = ()
     pass
+
+
+class LoggingConfigError(Sqlite2pgError):
+    """Represents an error in logging configuration."""
+
+    __slots__: typing.Sequence[str] = ()
+    pass
